@@ -19,7 +19,6 @@
  */
 
 #include "kateprojectplugin.h"
-#include "kateprojectplugin.moc"
 
 #include "kateproject.h"
 #include "kateprojectconfigpage.h"
@@ -239,7 +238,10 @@ void KateProjectPlugin::slotDirectoryChanged(const QString &path)
     QString fileName = QDir(path).filePath(ProjectFileName);
     for (KateProject * project : m_projects) {
         if (project->fileName() == fileName) {
-            project->reload();
+            QDateTime lastModified = QFileInfo(fileName).lastModified();
+            if (project->fileLastModified().isNull() || (lastModified > project->fileLastModified())) {
+                project->reload();
+            }
             break;
         }
     }
